/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 2.1.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Juhapekka Piiroinen <juhapekka.piiroinen@canonical.com>
 */

import QtQuick 1.1

Rectangle {
    color: "#F7F6F5"

    property int maximumWidth : 900
    property int maximumHeight: 579

    Image {
         anchors.fill: parent
         fillMode: Image.Tile
         source: "images/bg_dotted.png"
    }

    Rectangle {
        anchors.centerIn: parent
        width: parent.width>maximumWidth ? maximumWidth : parent.width
        height: (parent.height>maximumHeight ? maximumHeight : parent.height) / 1.2
        color: "#FFF"

        Image {
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            source: "images/devices.png"
            height: parent.height
            width: parent.width/2
            fillMode: Image.PreserveAspectFit
        }

        Rectangle {
            color: "transparent"
            anchors.margins: 20
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width - anchors.margins*2

            Column {
                spacing: 20
                anchors.top: parent.top
                anchors.left: parent.left
                width: parent.width/2

                Text {
                    width: parent.width
                    wrapMode: Text.WordWrap
                    font.family: "Ubuntu"
                    font.weight: Font.Light
                    font.pointSize: 42
                    font.letterSpacing: 2
                    text: "Make it Ubuntu"
                }

                Text {
                    wrapMode: Text.WordWrap
                    width: parent.width
                    font.family: "Ubuntu"
                    font.weight: Font.Light
                    font.pointSize: 20
                    font.letterSpacing: 1.5
                    text: "Get started today with the Ubuntu SDK Preview and the App Design Guides."
                }
            }

            Column {
                   anchors.verticalCenter: parent.verticalCenter
                    spacing: 5
                    Text {
                        wrapMode: Text.WordWrap
                        width: parent.width
                        font.family: "Ubuntu"
                        font.pixelSize: 20
                        font.letterSpacing: 1.5
                        font.weight: Font.Light
                        textFormat: Text.RichText
                        text: "<a style=\"text-decoration: none; color: #DD4814\" href=\"http://design.ubuntu.com/apps\">Design something beautiful &gt;</a>"
                        onLinkActivated: {
                            Qt.openUrlExternally(link);
                        }
                    }

                    Text {
                        id: demo
                        wrapMode: Text.WordWrap
                        width: parent.width
                        font.family: "Ubuntu"
                        font.pixelSize: 20
                        font.letterSpacing: 1.5
                        font.weight: Font.Light
                        textFormat: Text.RichText
                        text: "<a style=\"text-decoration: none; color: #DD4814\" href=\"http://developer.ubuntu.com/api/ubuntu-12.10/qml/mobile/overview-ubuntu-sdk.html\">Build something solid &gt;</a>"
                        onLinkActivated: {
                            Qt.openUrlExternally(link);
                        }

                    }
            }

            Column {
                anchors.bottom: parent.bottom
                anchors.left: parent.left

                    width: parent.width
                    spacing: 5
                    Text {
                        wrapMode: Text.WordWrap
                        width: parent.width
                        font.family: "Ubuntu"
                        font.pixelSize: 26
                        font.weight: Font.Light
                        text: "Get in touch"
                    }

                    Text {
                        wrapMode: Text.WordWrap
                        width: parent.width
                        font.family: "Ubuntu"
                        font.pixelSize: 18
                        font.weight: Font.Light
                        text: "By joining our <a style=\"text-decoration: none; color: #DD4814\" href=\"http://wiki.ubuntu.com/Touch/Contribute#Discuss\">mailing list</a> and for real-time communication join <a style=\"text-decoration: none; color: #DD4814\" href=\"http://webchat.freenode.net/?channels=ubuntu-touch\">#ubuntu-touch</a> on freenode."
                        onLinkActivated: {
                            Qt.openUrlExternally(link);
                        }
                    }

            }

        }
    }
}

